'''
file __init__.py


'''

import geocode

Readboundry = geocode.paser.Readboundry
